translate.convert.po2html

Package translate :: Package convert :: Module po2html |
[hide private]
[frames] | no frames]

# Module po2html

source code

convert Gettext PO localization files to HTML files

see: http://translate.sourceforge.net/wiki/toolkit/po2html for examples and usage instructions

Classes | [hide private]
| po2html po2html can take a po file and generate html.

Functions | [hide private]
converthtml(inputfile, outputfile, templatefile, wrap=None, includefuzzy=False, usetidy=True) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Variables | [hide private]
| textwrap = `None` Parse an instance of this class from the start of the given string.
| tidy = `None` Parse an instance of this class from the start of the given string.

Imports: po